===============================
metropack
===============================

.. image:: https://img.shields.io/travis/eddiejessup/metropack.svg
        :target: https://travis-ci.org/eddiejessup/metropack

.. image:: https://img.shields.io/pypi/v/metropack.svg
        :target: https://pypi.python.org/pypi/metropack


Pack spheres in a finite space

* Free software: BSD license
* Documentation: https://metropack.readthedocs.org.

Features
--------

* TODO
